from setuptools import setup

setup(
    name='kedsort-cli',
    version='0.1.2',
    py_modules=['idk'],
    install_requires=[
        'Click',
        'PyPDF2',
    ],
    entry_points='''
        [console_scripts]
        pdfsort=pdfsort:cli
        kedsort=pdfsort:kedsort
    ''',
)



import PyPDF2
import sys

def rotate_all(input_pdf, output_pdf, degrees):
    pdf_in = open(input_pdf, 'rb')
    pdf_reader = PyPDF2.PdfFileReader(pdf_in, False)
    pdf_writer = PyPDF2.PdfFileWriter()
    for pagenum in range(pdf_reader.numPages):
        page = pdf_reader.getPage(pagenum)
        page.rotateClockwise(degrees)
        pdf_writer.addPage(page)
    pdf_out = open(output_pdf, 'wb')
    pdf_writer.write(pdf_out)
    pdf_out.close()
    pdf_in.close()



import click
import PyPDF2
import sys
from list_numbers import list_numbers

def generate_new_pdf(input_pdf, pages_list, output_pdf):
    ''' Create a new pdf from a given list of pages '''
    pages_list = list_numbers(pages_list)
    pdf_in = open(input_pdf, 'rb')
    pdf_reader = PyPDF2.PdfFileReader(pdf_in)
    pdf_writer = PyPDF2.PdfFileWriter()
    for index in range(pdf_reader.numPages):
        new_page = pdf_reader.getPage(index)
        if index in pages_list:
            new_page = pdf_reader.getPage(index)
            string = "added page: " + str(index+1)
            pdf_writer.addPage(new_page)
            click.secho(string, fg='blue')

    pdf_out = open(output_pdf, 'wb')
    pdf_writer.write(pdf_out)
    pdf_out.close()
    pdf_in.close()



def list_numbers(nums):
    final_arr = []
    arr = nums.split(',')
    for thing in arr:
        if "-" not in thing:
            final_arr.append(int(thing) - 1)
        else:
            t = thing.split("-")
            for i in range(int(t[0]), int(t[1]) + 1):
                final_arr.append(int(i) - 1)
    return final_arr



import click
import os
import PyPDF2

def split_pure_python(pdf, first_page, last_page, outputpdf):
    pdf_in = open(pdf, 'rb')
    pdf_reader = PyPDF2.PdfFileReader(pdf_in)
    pdf_writer = PyPDF2.PdfFileWriter()
    for page in range(first_page - 1, last_page):
        new_page = pdf_reader.getPage(page)
        pdf_writer.addPage(new_page)

    pdf_out = open(outputpdf, 'wb')
    pdf_writer.write(pdf_out)
    pdf_out.close()
    pdf_in.close()
    string = "Created " + outputpdf
    click.secho(string, fg='blue')

def loop_scripts(pdf, start_page, total_pages, increment, outputpdf):
    current_page = start_page
    for index in range(start_page, total_pages+1):
        if (current_page < total_pages):
            pdfName = outputpdf.replace(".pdf", "") + "-" + str(index) + ".pdf"
            last_page = current_page + increment - 1
            if last_page > total_pages:
                last_page = total_pages
            split_pure_python(pdf, current_page, last_page, pdfName)
            current_page = current_page + increment



import click
import PyPDF2
import sys
from list_numbers import list_numbers

def rotate_pages_by_degrees(pdf, pages_list, output_pdf, clockwise_rotation_in_degrees):
    pages_list = list_numbers(pages_list)
    pdf_in = open(pdf, 'rb')
    pdf_reader = PyPDF2.PdfFileReader(pdf_in)
    pdf_writer = PyPDF2.PdfFileWriter()
    for index in range(pdf_reader.numPages):
        new_page = pdf_reader.getPage(index)
        if index in pages_list:
            new_page = pdf_reader.getPage(index)
            string = "rotated page: " + str(index + 1) + " " + str(clockwise_rotation_in_degrees) + " degrees"
            new_page.rotateClockwise(clockwise_rotation_in_degrees)
            click.secho(string, fg='blue')
        pdf_writer.addPage(new_page)
    pdf_out = open(output_pdf, 'wb')
    pdf_writer.write(pdf_out)
    pdf_out.close()
    pdf_in.close()



import click
import time
import PyPDF2
import os
import sys

from rotate_all import rotate_all as rotate_function
from generate_new_pdf import generate_new_pdf
from rotate_pages_by_degrees import rotate_pages_by_degrees
from split import loop_scripts

@click.group(invoke_without_command=False)
@click.pass_context
def cli(ctx):
    pass
    # click.secho('Starting pdfsort %s' % ctx.invoked_subcommand, fg="white", bg="blue")

@cli.command()
@click.option('--degrees', default=180, help='degrees to rotate by')
@click.argument('input_pdf')
@click.argument('output_pdf')
def rotate_all(input_pdf, output_pdf, degrees):
    time1 = time.time()
    description = "\nRotating " + input_pdf + " by " + str(degrees) + " degrees"
    click.secho(description, fg='green')
    rotate_function(input_pdf, output_pdf, degrees)
    click.secho("Created: " + output_pdf, fg='green')
    time2 = time.time()
    time_string = '%0.3f seconds' % ((time2-time1))
    click.secho(time_string, fg='green')

@cli.command()
@click.argument('input_pdf')
@click.argument('output_pdf')
@click.argument('pages_list')
def generate(input_pdf, output_pdf, pages_list):
    time1 = time.time()
    description = "\nCreating " + output_pdf + " from " + input_pdf + " pages " + pages_list
    click.secho(description, fg='green')

    generate_new_pdf(input_pdf, pages_list, output_pdf)

    click.secho("Created: " + output_pdf, fg='green')
    time2 = time.time()
    time_string = '%0.3f seconds' % ((time2-time1))
    click.secho(time_string, fg='green')

@cli.command()
@click.argument('input_pdf')
@click.argument('output_pdf')
@click.argument('pages_list')
@click.argument('degrees')
def rotate_pages(input_pdf, output_pdf, pages_list, degrees):
    time1 = time.time()
    description = "\nRotating pages " + pages_list + " " + degrees + " from " + input_pdf + " to " + output_pdf
    click.secho(description, fg='green')

    rotate_pages_by_degrees(input_pdf, pages_list, output_pdf, int(degrees))

    click.secho("Created: " + output_pdf, fg='green')
    time2 = time.time()
    time_string = '%0.3f seconds' % ((time2-time1))
    time_string = "Finished rotating all pages: " + time_string
    click.secho(time_string, fg='green')

@cli.command()
@click.argument('input_pdf')
@click.argument('output_pdf')
@click.argument('first_page')
@click.argument('last_page')
@click.argument('increment')
def split(input_pdf, output_pdf, first_page, last_page, increment):
    time1 = time.time()
    description = "\nSplitting " + input_pdf
    click.secho(description, fg='green')

    loop_scripts(input_pdf, int(first_page), int(last_page), int(increment), output_pdf)

    time2 = time.time()
    time_string = '%0.3f seconds' % ((time2-time1))
    time_string = "Finished splitting into individual canvass files: " + time_string
    click.secho(time_string, fg='green')

@cli.command()
@click.argument('input_pdf')
@click.option('--tracker_pages')
@click.option('--sign_in_pages')
@click.option('--canvass_pages')
@click.option('--increment')

def kedsort(self, input_pdf, tracker_pages, sign_in_pages, canvass_pages, increment):
    click.secho('Starting kedsort\n', fg="green")

    time1 = time.time()

    tracker_pages = tracker_pages.replace(" ", "")
    sign_in_pages = sign_in_pages.replace(" ", "")
    canvass_pages = canvass_pages.replace(" ", "")

    if tracker_pages:
        if not os.path.exists('trackers'):
            os.makedirs('trackers')
        tracker_pdf = "trackers/" + input_pdf.replace(" ", "").replace(".pdf", "") + "-tracker.pdf"
        click.secho("Adding tracker pages", fg='green')

        generate_new_pdf(input_pdf, tracker_pages, tracker_pdf)

    if sign_in_pages:
        if not os.path.exists('sign_ins'):
            os.makedirs('sign_ins')
        sign_in_pdf = "sign_ins/" + input_pdf.replace(" ", "").replace(".pdf", "") + "-sign_in.pdf"
        click.secho("Adding sign in pages", fg='green')

        generate_new_pdf(input_pdf, sign_in_pages, sign_in_pdf)

    if canvass_pages:
        if not os.path.exists('canvass'):
            os.makedirs('canvass')
        canvass_pdf = input_pdf.replace(" ", "").replace(".pdf", "") + "-canvass.pdf"
        click.secho("Adding canvass pages", fg='green')

        generate_new_pdf(input_pdf, canvass_pages, "canvass/" + canvass_pdf)

        if increment:
            if not os.path.exists('canvass/individual'):
                os.makedirs('canvass/individual')
            total_pages = PyPDF2.PdfFileReader("canvass/" + canvass_pdf, False).getNumPages()
            click.secho("Splitting canvass pages", fg='green')

            loop_scripts("canvass/" + canvass_pdf, 1, total_pages, int(increment), "canvass/individual/" + canvass_pdf)

    time2 = time.time()
    time_string = '%0.3f seconds' % ((time2-time1))
    time_string = "Total time: " + time_string
    click.secho(time_string, fg='green')

def main():
    input_pdf = None
    tracker_pages = None
    sign_in_pages = None
    canvass_pages = None
    increment = None

    try:
        if sys.argv.index('--input'):
            input_pdf = sys.argv[sys.argv.index('--input') + 1]
    except:
        print "Must include --input"

    try:
        if sys.argv.index('--tracker_pages'):
            tracker_pages = sys.argv[sys.argv.index('--tracker_pages') + 1]
    except:
        pass

    try:
        if sys.argv.index('--canvass_pages'):
            canvass_pages = sys.argv[sys.argv.index('--canvass_pages') + 1]
    except:
        pass

    try:
        if sys.argv.index('--sign_in_pages'):
            sign_in_pages = sys.argv[sys.argv.index('--sign_in_pages') + 1]
    except:
        pass

    try:
        if sys.argv.index('--increment'):
            increment = sys.argv[sys.argv.index('--increment') + 1]
    except:
        pass
    print "input_pdf: " + str(input_pdf)
    print "tracker_pages: " + str(tracker_pages)
    print "canvass_pages: " + str(canvass_pages)
    print "sign_in_pages: " + str(sign_in_pages)
    print "increment: " + str(increment)

    # kedsort(input_pdf, tracker_pages, sign_in_pages, canvass_pages, increment)

if __name__ == "__main__":
    print sys.argv



from distutils.core import setup
setup(
  name = 'kedsort',
  packages = ['kedsort'], # this must be the same as the name above
  version = '0.1.8',
  description = 'sort pdfs',
  author = 'Andy Gimma',
  author_email = 'andy.n.gimma@gmail.com',
  url = 'https://github.com/andygimma/pdfsort_cli', # use the URL to the github repo
  download_url = 'https://github.com/andygimma/pdfsort_cli/archive/0.1.tar.gz', # I'll explain this in a second
  keywords = ['pdf'],
  classifiers = [],
)
